@@ -67,7 +67,7 @@ def check():
         exit(0)
 
     print('Start check. This may take a minute..')
-    subprocess.call('inspec exec /vagrant/training/ --reporter json:/vagrant/tmp/result.json', shell=True, stderr=subprocess.DEVNULL, stdout=subprocess.DEVNULL)
+    subprocess.call('sudo inspec exec /vagrant/training/ --reporter json:/vagrant/tmp/result.json', shell=True, stderr=subprocess.DEVNULL, stdout=subprocess.DEVNULL)
     print()
     print("Check done. Here are your results:")
     print()
@@ -144,8 +144,6 @@ def main():
 
     # Print Result
 
-    print()
-    print("Result for Training: " + result_json['profiles'][0]['title'])
     print("Training id        : " + result_json['profiles'][0]['name'])
     print("Instructions       : " + 'https://admindojo.org/instructions/' + result_json['profiles'][0]['name'])
 
@@ -223,6 +221,10 @@ def main():
     with open(os.path.normpath(os.path.join(path_training, player_result.TrainingID) + "-timeNeeded" + ".txt"), 'w') as f:
         f.write(str(player_result.PlayerTimeNeeded))
 
+    if player_result.getResult():
+        with open(os.path.normpath(os.path.join(path_training, player_result.TrainingID) + "-token" + ".txt"), 'w') as f:
+            f.write(str(token))
+
     print("Result saved!")
 
 
